<!-- This page is formatted for GitHub's markdown renderer -->
![AIQC (wide)](https://raw.githubusercontent.com/aiqc/aiqc/main/docs/images/aiqc_logo_banner_controlroom.png)

<br />

<h3 align='center'>📚&nbsp;&nbsp;<a href="https://aiqc.readthedocs.io/">Documentation</a></h3>

<h3 align='center'>🛡️&nbsp;&nbsp;<a href="https://aiqc.readthedocs.io/en/latest/community.html">Community</a></h3>

<br />

---

<br />

<p align='center'><b>Deep learning experiment tracking that's rapid, rigorous, & reproducible.</b></p>

<p align='center'><i>On a mission to accelerate open science by making deep learning more accessible.</i></p>

<br />


<p align="center">
	<img src="https://raw.githubusercontent.com/aiqc/aiqc/main/docs/images/framework_june14.png" alt="framework"/>
</p>

<br />

* Achieve end-to-end reproducibility by recording both data preparation & training experiments.
* Easily orchestrate parameterized protocols for data preprocessing & model evalaution.


---

<br />

<p align='center'><i>Thanks to the support and sponsorship of:</i></p>

<br />


<p align="center">
	<img src="https://raw.githubusercontent.com/aiqc/aiqc/main/docs/images/psf_wide.png" alt="sponsor"/>
</p>